import os

TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "test_data")
CORRECT_METADATA_DIR = os.path.join(TEST_DATA_DIR, "correct-metadata")
MISSING_METADATA_DIR = os.path.join(TEST_DATA_DIR, "missing-metadata")
